==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+76"/>
        <source>First line, arc or circle</source>
        <translation>Primera línea, arco, círculo</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Segunda línea, arco, círculo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Seleccionar solución</translation>
    </message>
    <message>
        <location line="+97"/>
        <location line="+94"/>
        <source>No solution</source>
        <translation>Ninguna solución</translation>
    </message>
    <message>
        <location line="-44"/>
        <source>Invalid radius</source>
        <translation>Radio no válido</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Radio:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 &amp;tangentes y radio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Dibuja un círculo tangente a dos entidades con un radio</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2TR/ts/Circle2TR_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Circle2TR</name>
    <message>
        <location filename="../Circle2TR.js" line="+77"/>
        <source>First line, arc or circle</source>
        <translation>Primera línea, arco, círculo</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second line, arc or circle</source>
        <translation>Segunda línea, arco, círculo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Choose solution</source>
        <translation>Seleccionar solución</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>No solution</source>
        <translation>Ninguna solución</translation>
    </message>
    <message>
        <source>Invalid radius</source>
        <translation type="vanished">Radio no válido</translation>
    </message>
    <message>
        <location filename="../Circle2TR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Radio:</translation>
    </message>
    <message>
        <location filename="../Circle2TRInit.js" line="+2"/>
        <source>2 &amp;Tangents and Radius</source>
        <translation>2 &amp;tangentes y radio</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle tangential to two entities with given radius</source>
        <translation>Dibuja un círculo tangente a dos entidades con un radio</translation>
    </message>
</context>
</TS>
